Router Clusters
===============

.. contents:: :local:

---------------

RouterCluster
-------------

* :class:`cfxdb.mrealm.RouterCluster`
* :class:`cfxdb.mrealmschema.RouterClusters`
* :class:`cfxdb.mrealmschema.IndexRouterClusterByName`
* :class:`cfxdb.mrealm.RouterClusterNodeMembership`
* :class:`cfxdb.mrealmschema.RouterClusterNodeMemberships`

-------

.. autoclass:: cfxdb.mrealm.RouterCluster
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.RouterClusters
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.IndexRouterClusterByName
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealm.RouterClusterNodeMembership
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.RouterClusterNodeMemberships
    :members:
    :show-inheritance:


RouterWorkerGroup
-----------------

* :class:`cfxdb.mrealm.RouterWorkerGroup`
* :class:`cfxdb.mrealmschema.RouterWorkerGroups`
* :class:`cfxdb.mrealmschema.IndexWorkerGroupByCluster`
* :class:`cfxdb.mrealmschema.IndexWorkerGroupByPlacement`
* :class:`cfxdb.mrealm.RouterWorkerGroupClusterPlacement`
* :class:`cfxdb.mrealmschema.RouterWorkerGroupClusterPlacements`
* :class:`cfxdb.mrealmschema.IndexClusterPlacementByWorkerName`

-------

.. autoclass:: cfxdb.mrealm.RouterWorkerGroup
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.RouterWorkerGroups
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.IndexWorkerGroupByCluster
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.IndexWorkerGroupByPlacement
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealm.RouterWorkerGroupClusterPlacement
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.RouterWorkerGroupClusterPlacements
    :members:
    :show-inheritance:

.. autoclass:: cfxdb.mrealmschema.IndexClusterPlacementByWorkerName
    :members:
    :show-inheritance:
